﻿using System;
using System.IO;

using Newtonsoft.Json;

namespace TestConsole
{
    /// <summary>
    /// 프로그램
    /// </summary>
    class Program
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Private

        #region 프로그램 실행하기 - Main(argumentArray)

        /// <summary>
        /// 프로그램 실행하기
        /// </summary>
        /// <param name="argumentArray">인자 배열</param>
        private static void Main(string[] argumentArray)
        {
            #region 프로그램 인자를 조사한다.

            if(argumentArray == null || argumentArray.Length < 2)
            {
                Console.WriteLine("구성 파일 경로를 표시하는 인자를 지정해 주시기 바랍니다.");

                return;
            }

            #endregion
            #region 구성 파일 경로를 설정한다.

            string configurationFilePath = argumentArray[1].Trim();

            Console.WriteLine("구성 파일 경로 : {0}", configurationFilePath);

            #endregion
            #region 구성 JSON 문자열을 설정한다.

            string configurationJSON = null;

            try
            {
                configurationJSON = File.ReadAllText(configurationFilePath);
            }
            catch(Exception exception)
            {
                Console.WriteLine("구성 파일 로드시 에러가 발생했습니다.");
                Console.WriteLine(exception.Message);

                return;
            }

            Console.WriteLine("구성 JSON 문자열");
            Console.WriteLine("--------------------------------------------------");
            Console.WriteLine(configurationJSON);
            Console.WriteLine("--------------------------------------------------");

            #endregion
            #region 구성 객체를 설정한다.

            Configuration configuration = null;

            try
            {
                configuration = JsonConvert.DeserializeObject<Configuration>(configurationJSON);
            }
            catch(Exception exception)
            {
                Console.WriteLine("구성 객체 설정시 에러가 발생했습니다.");
                Console.WriteLine(exception.Message);

                return;
            }

            #endregion

            string sourceDirectoryPath = configuration.SourceDirectoryPath.Replace
            (
                configuration.MappingSourceRootDirectoryPath,
                configuration.MappingTargetRootDirectoryPath
            );

            string resultDirectoryPath = configuration.ResultDirectoryPath.Replace
            (
                configuration.MappingSourceRootDirectoryPath,
                configuration.MappingTargetRootDirectoryPath
            );

            Console.WriteLine("소스 디렉토리 경로 : {0}", sourceDirectoryPath);
            Console.WriteLine("결과 디렉토리 경로 : {0}", resultDirectoryPath);

            string sourceMessageFilePath = Path.Combine(sourceDirectoryPath, "SourceMessage.dat");
            string resultMessageFilePath = Path.Combine(resultDirectoryPath, "ResultMessage.dat");

            Console.WriteLine("소스 메시지 파일 경로 : {0}", sourceMessageFilePath);
            Console.WriteLine("결과 메시지 파일 경로 : {0}", resultMessageFilePath);

            #region 결과 메시지 파일이 존재하는 경우 삭제한다.

            if(File.Exists(resultMessageFilePath))
            {
                File.SetAttributes(resultMessageFilePath, FileAttributes.Normal);

                File.Delete(resultMessageFilePath);
            }

            #endregion

            File.Copy(sourceMessageFilePath, resultMessageFilePath);
        }

        #endregion
    }
}